// Code generated by lark_sdk_gen. DO NOT EDIT.
/**
 * Copyright 2022 chyroc
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package lark

import (
	"context"
)

// GetACSAccessRecordList 用户在门禁考勤机上成功开门或打卡后, 智能门禁应用都会生成一条门禁记录。
//
// 该接口返回满足查询参数的识别记录
//
// doc: https://open.feishu.cn/document/uAjLw4CM/ukTMukTMukTM/acs-v1/access_record/list
func (r *ACSService) GetACSAccessRecordList(ctx context.Context, request *GetACSAccessRecordListReq, options ...MethodOptionFunc) (*GetACSAccessRecordListResp, *Response, error) {
	if r.cli.mock.mockACSGetACSAccessRecordList != nil {
		r.cli.log(ctx, LogLevelDebug, "[lark] ACS#GetACSAccessRecordList mock enable")
		return r.cli.mock.mockACSGetACSAccessRecordList(ctx, request, options...)
	}

	req := &RawRequestReq{
		Scope:                 "ACS",
		API:                   "GetACSAccessRecordList",
		Method:                "GET",
		URL:                   r.cli.openBaseURL + "/open-apis/acs/v1/access_records",
		Body:                  request,
		MethodOption:          newMethodOption(options),
		NeedTenantAccessToken: true,
	}
	resp := new(getACSAccessRecordListResp)

	response, err := r.cli.RawRequest(ctx, req, resp)
	return resp.Data, response, err
}

// MockACSGetACSAccessRecordList mock ACSGetACSAccessRecordList method
func (r *Mock) MockACSGetACSAccessRecordList(f func(ctx context.Context, request *GetACSAccessRecordListReq, options ...MethodOptionFunc) (*GetACSAccessRecordListResp, *Response, error)) {
	r.mockACSGetACSAccessRecordList = f
}

// UnMockACSGetACSAccessRecordList un-mock ACSGetACSAccessRecordList method
func (r *Mock) UnMockACSGetACSAccessRecordList() {
	r.mockACSGetACSAccessRecordList = nil
}

// GetACSAccessRecordListReq ...
type GetACSAccessRecordListReq struct {
	PageSize   *int64  `query:"page_size" json:"-"`    // 分页大小, 示例值: 100, 默认值: `100`, 最大值: `500`
	PageToken  *string `query:"page_token" json:"-"`   // 分页标记, 第一次请求不填, 表示从头开始遍历；分页查询结果还有更多项时会同时返回新的 page_token, 下次遍历可采用该 page_token 获取查询结果, 示例值: "AQD9/Rn9eij9Pm39ED40/dk53s4Ebp882DYfFaPFbz00L4CMZJrqGdzNyc8BcZtDbwVUvRmQTvyMYicnGWrde9X56TgdBuS+JKiSIkdexPw="
	From       int64   `query:"from" json:"-"`         // 记录开始时间, 单位秒, 示例值: 1624520521
	To         int64   `query:"to" json:"-"`           // 记录结束时间, 单位秒, 时间跨度不能超过30天, 示例值: 1624520521
	DeviceID   *string `query:"device_id" json:"-"`    // 门禁设备 ID, 示例值: "7091146989218002577"
	UserIDType *IDType `query:"user_id_type" json:"-"` // 用户 ID 类型, 示例值: "open_id", 可选值有: open_id: 用户的 open id, union_id: 用户的 union id, user_id: 用户的 user id, 默认值: `open_id`, 当值为 `user_id`, 字段权限要求: 获取用户 user ID
}

// GetACSAccessRecordListResp ...
type GetACSAccessRecordListResp struct {
	Items     []*GetACSAccessRecordListRespItem `json:"items,omitempty"`
	PageToken string                            `json:"page_token,omitempty"` // 分页标记, 当 has_more 为 true 时, 会同时返回新的 page_token, 否则不返回 page_token
	HasMore   bool                              `json:"has_more,omitempty"`   // 是否还有更多项
}

// GetACSAccessRecordListRespItem ...
type GetACSAccessRecordListRespItem struct {
	AccessRecordID string `json:"access_record_id,omitempty"` // 门禁记录 ID
	UserID         string `json:"user_id,omitempty"`          // 门禁记录所属用户 ID
	DeviceID       string `json:"device_id,omitempty"`        // 门禁设备 ID
	IsClockIn      bool   `json:"is_clock_in,omitempty"`      // 是否是打卡
	AccessTime     string `json:"access_time,omitempty"`      // 访问时间, 单位秒
	AccessType     string `json:"access_type,omitempty"`      // 识别方式, 可选值有: FA: 人脸识别方式
	AccessData     string `json:"access_data,omitempty"`      // 识别相关数据, 根据 access_type 不同, 取值不同
	IsDoorOpen     bool   `json:"is_door_open,omitempty"`     // 是否开门
}

// getACSAccessRecordListResp ...
type getACSAccessRecordListResp struct {
	Code int64                       `json:"code,omitempty"` // 错误码, 非 0 表示失败
	Msg  string                      `json:"msg,omitempty"`  // 错误描述
	Data *GetACSAccessRecordListResp `json:"data,omitempty"`
}
