// Code generated by lark_sdk_gen. DO NOT EDIT.
/**
 * Copyright 2022 chyroc
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package lark

import (
	"context"
)

// SortChatTab 会话标签页排序。
//
// 注意事项:
// - 应用需要开启[机器人能力](https://open.feishu.cn/document/uAjLw4CM/ugTN1YjL4UTN24CO1UjN/trouble-shooting/how-to-enable-bot-ability)
// - 机器人或授权用户必须在群里
// - 消息标签页强制固定为第一顺位, 不参与排序, 但是请求体中必须包含该标签页的Tab ID
// - 操作内部群时, 操作者须与群组在同一租户下
//
// doc: https://open.feishu.cn/document/uAjLw4CM/ukTMukTMukTM/reference/im-v1/chat-tab/sort_tabs
func (r *ChatService) SortChatTab(ctx context.Context, request *SortChatTabReq, options ...MethodOptionFunc) (*SortChatTabResp, *Response, error) {
	if r.cli.mock.mockChatSortChatTab != nil {
		r.cli.log(ctx, LogLevelDebug, "[lark] Chat#SortChatTab mock enable")
		return r.cli.mock.mockChatSortChatTab(ctx, request, options...)
	}

	req := &RawRequestReq{
		Scope:                 "Chat",
		API:                   "SortChatTab",
		Method:                "POST",
		URL:                   r.cli.openBaseURL + "/open-apis/im/v1/chats/:chat_id/chat_tabs/sort_tabs",
		Body:                  request,
		MethodOption:          newMethodOption(options),
		NeedTenantAccessToken: true,
		NeedUserAccessToken:   true,
	}
	resp := new(sortChatTabResp)

	response, err := r.cli.RawRequest(ctx, req, resp)
	return resp.Data, response, err
}

// MockChatSortChatTab mock ChatSortChatTab method
func (r *Mock) MockChatSortChatTab(f func(ctx context.Context, request *SortChatTabReq, options ...MethodOptionFunc) (*SortChatTabResp, *Response, error)) {
	r.mockChatSortChatTab = f
}

// UnMockChatSortChatTab un-mock ChatSortChatTab method
func (r *Mock) UnMockChatSortChatTab() {
	r.mockChatSortChatTab = nil
}

// SortChatTabReq ...
type SortChatTabReq struct {
	ChatID string   `path:"chat_id" json:"-"`  // 群ID, 详情参见[群ID 说明](https://open.feishu.cn/document/uAjLw4CM/ukTMukTMukTM/reference/im-v1/chat-id-description), 注意: 支持群模式为`p2p`与`group`的群ID, 示例值: "oc_a0553eda9014c201e6969b478895c230"
	TabIDs []string `json:"tab_ids,omitempty"` // 会话标签页ID列表, Tab ID可以在[添加会话标签页](https://open.feishu.cn/document/uAjLw4CM/ukTMukTMukTM/reference/im-v1/chat-tab/create)与[拉取会话标签页](https://open.feishu.cn/document/uAjLw4CM/ukTMukTMukTM/reference/im-v1/chat-tab/list_tabs)的返回值中获取, 注意: 必须包含该会话中全部的Tab ID, 示例值: ["7101214603622940671", "7101214603622940672"]
}

// SortChatTabResp ...
type SortChatTabResp struct {
	ChatTabs []*SortChatTabRespChatTab `json:"chat_tabs,omitempty"` // 会话标签页
}

// SortChatTabRespChatTab ...
type SortChatTabRespChatTab struct {
	TabID      string                            `json:"tab_id,omitempty"`      // Tab ID
	TabName    string                            `json:"tab_name,omitempty"`    // Tab名称, 注意: 会话标签页的名称不能超过30个字符
	TabType    string                            `json:"tab_type,omitempty"`    // Tab类型, 可选值有: message: 消息类型, doc_list: 云文档列表, doc: 文档, pin: Pin, meeting_minute: 会议纪要, chat_announcement: 群公告, url: URL, file: 文件
	TabContent *SortChatTabRespChatTabTabContent `json:"tab_content,omitempty"` // Tab内容
	TabConfig  *SortChatTabRespChatTabTabConfig  `json:"tab_config,omitempty"`  // Tab的配置
}

// SortChatTabRespChatTabTabConfig ...
type SortChatTabRespChatTabTabConfig struct {
	IconKey   string `json:"icon_key,omitempty"`    // 群Tab图标
	IsBuiltIn bool   `json:"is_built_in,omitempty"` // 群tab是否App内嵌打开
}

// SortChatTabRespChatTabTabContent ...
type SortChatTabRespChatTabTabContent struct {
	URL           string `json:"url,omitempty"`            // URL类型
	Doc           string `json:"doc,omitempty"`            // Doc链接
	MeetingMinute string `json:"meeting_minute,omitempty"` // 会议纪要
}

// sortChatTabResp ...
type sortChatTabResp struct {
	Code int64            `json:"code,omitempty"` // 错误码, 非 0 表示失败
	Msg  string           `json:"msg,omitempty"`  // 错误描述
	Data *SortChatTabResp `json:"data,omitempty"`
}
